@@ -90,6 +90,8 @@ class QHstats(object):
         if "Comments" in cols:
             cols.remove("Comments")
             data.drop(["Comments"], axis=1, inplace=True)  # type: ignore
+        if "VEI" in cols:
+            data["VEI"] = data["VEI"].fillna(0).astype(int)
         if "Climate zone" in cols:
             data["Climate zone"] = pd.Categorical(
                 data["Climate zone"],  # type: ignore
